API Reference — Carrot v0.8.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.8.0 documentation »

# API Reference

Release: | 0.8
Date: | November 16, 2009

- carrot.connection
- carrot.messaging
- carrot.backends
- carrot.backends.base
- carrot.backends.pyamqplib
- carrot.backends.pystomp
- carrot.backends.queue
- carrot.serialization

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.8.0 documentation »